<?php
/**
 * The Giapeto script to edit bookmarks.
 *
 * $Horde: giapeto/bookmarks/edit.php,v 1.21 2007/01/02 12:47:37 jan Exp $
 *
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */

@define('GIAPETO_BASE', dirname(__FILE__) . '/..');
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only registered users should be using this. */
if (!Auth::getAuth()) {
    Horde::authenticationFailureRedirect();
}

/* Set up the giapeto object. */
$giapeto = &Giapeto::singleton();

/* Get some variables. */
$vars = Variables::getDefaultVariables();
$bookmark_id = $vars->get('bookmark_id');

$form = new Horde_Form($vars, _("Bookmark"));

/* Check if a bookmark is being edited. */
if ($bookmark_id && !$form->isSubmitted()) {
    $vars = new Variables($bookmarks->getBookmark($bookmark_id));
}

$bookmark_alert = $vars->get('bookmark_alert');

/* Get the site tree to allow the user to a different page. */
$sitetree = $giapeto->getSiteTree('cat_ids', -1, false, true);

/* Set up the form. */
$form->setButtons(_("Save this bookmark"));
$form->addHidden('', 'bookmark_id', 'int', false);
$form->addVariable(_("Page"), 'page_id', 'enum', false, false, null, array($sitetree));
$v = &$form->addVariable(_("Alert on updates"), 'bookmark_alert', 'boolean', false);
$v->setHelp('bookmark-alert');
$v->setAction(Horde_Form_Action::factory('submit'));
$v->setOption('trackchange', true);
if (!is_null($vars->get('formname')) &&
    $vars->get($v->getVarName()) != $vars->get('__old_' . $v->getVarName())) {
    $notification->push(_("Changed your alert preference."), 'horde.message');
}

/* If alerting on updates ask whether to monitor subpages too. */
if ($bookmark_alert) {
    $v = &$form->addVariable(_("Also watch subpages"), 'bookmark_subpages', 'boolean', false);
    $v->setHelp('bookmark-subpages');
}

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $form_id = $bookmarks->saveBookmark($info);
    if (is_a($bookmark_id, 'PEAR_Error')) {
        Horde::logMessage($bookmark_id, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Error saving bookmark. %s."), $bookmark_id->getMessage()), 'horde.error');
    } else {
        $notification->push(_("Bookmark details saved."), 'horde.success');
        $url = Horde::applicationUrl('bookmarks/index.php', true);
        header('Location: ' . $url);
        exit;
    }
}

/* Render the form. */
$renderer = new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

/* Get the bookmark list, done here to include any freshly added bookmark. */
$bookmark_list = $bookmarks->getBookmarks(true);

$template = new Horde_Template();
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));
$template->set('main', $main);

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/bookmarks/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
