<?php
/**
 * The Giapeto_Bookmarks_sql:: class provides the SQL driver for storing
 * Giapeto bookmarks.
 *
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/lib/Bookmarks/sql.php,v 1.21 2007/01/02 12:47:39 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */
class Giapeto_Bookmarks_sql extends Giapeto_Bookmarks {

    /**
     * Handle for the database connection.
     *
     * @var DB
     */
    var $_db;

    function saveBookmark(&$info)
    {
        if (empty($info['bookmark_id'])) {
            $sql = 'SELECT * FROM giapeto_bookmarks' .
                   ' WHERE page_id = ? AND user_uid = ?';
            $values = array((int)$info['page_id'], Auth::getAuth());
            $result = $this->_db->getRow($sql, $values, DB_FETCHMODE_ASSOC);
            if (!empty($result['bookmark_id'])) {
                $info['bookmark_id'] = $result['bookmark_id'];
            } else {
                $info['bookmark_id'] = $this->_db->nextId('giapeto_bookmarks');
                if (is_a($info['bookmark_id'], 'PEAR_Error')) {
                    return $info['bookmark_id'];
                }
            }
            /* Delete existing bookmark. */
            $sql = 'DELETE FROM giapeto_bookmarks' .
                   ' WHERE bookmark_id = ?';
            $values = array((int)$info['bookmark_id']);
            Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::saveBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
            $delete = $this->_db->query($sql, $values);
            if (is_a($delete, 'PEAR_Error')) {
                return $delete;
            }

            /* Save the updated bookmark. */
            $sql = 'INSERT INTO giapeto_bookmarks' .
                   ' (bookmark_id, user_uid, page_id, bookmark_alert, bookmark_subpages)' .
                   ' VALUES (?, ?, ?, ?, ?)';
            $values = array();
        } else {
            $sql = 'UPDATE giapeto_bookmarks' .
                   ' SET bookmark_id = ?, user_uid = ?, page_id = ?, bookmark_alert = ?, bookmark_subpages = ?' .
                   ' WHERE bookmark_id = ?';
            $values = array((int)$info['bookmark_id']);
        }

        array_unshift($values,
                      (int)$info['bookmark_id'],
                      Auth::getAuth(),
                      (int)$info['page_id'],
                      ($info['bookmark_alert'] ? '1' : '0'),
                      ($info['bookmark_subpages'] ? '1' : '0'));

        Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::saveBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql, $values);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        return $info['bookmark_id'];
    }

    function _getBookmarks()
    {
        $sql = 'SELECT * FROM giapeto_bookmarks WHERE user_uid = ?';
        $values = array(Auth::getAuth());

        $result = $this->_db->getAll($sql, $values, DB_FETCHMODE_ASSOC);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return array();
        }

        return $result;
    }

    function _getAllBookmarks()
    {
        return $this->_db->getAll('SELECT * FROM giapeto_bookmarks', DB_FETCHMODE_ASSOC);
    }

    function isBookmarked($page_id)
    {
        $sql = 'SELECT * FROM giapeto_bookmarks' .
               ' WHERE page_id = ? AND user_uid = ?';
        $values = array((int)$page_id, Auth::getAuth());
        $result = $this->_db->getOne($sql, $values);
        return (!empty($result));
    }

    function getBookmark($bookmark_id, $with_path = false)
    {
        $sql = 'SELECT * FROM giapeto_bookmarks' .
               ' WHERE bookmark_id = ? AND user_uid = ?';
        $values = array((int)$bookmark_id, Auth::getAuth());
        Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::getBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getRow($sql, $values, DB_FETCHMODE_ASSOC);

        if ($with_path) {
            $result['path'] = $GLOBALS['registry']->call('cms/getPageUrl', array($result['page_id']));
        }

        return $result;
    }

    function deleteBookmark($bookmark_id)
    {
        /* Delete the form. */
        $sql = 'DELETE FROM giapeto_bookmarks WHERE bookmark_id = ?';
        $values = array((int)$bookmark_id);
        $delete = $this->_db->query($sql, $values);
        return $delete;
    }

    function initialise()
    {
        Horde::assertDriverConfig($this->_params, 'sql',
            array('phptype'));

        if (!isset($this->_params['database'])) {
            $this->_params['database'] = '';
        }
        if (!isset($this->_params['username'])) {
            $this->_params['username'] = '';
        }
        if (!isset($this->_params['hostspec'])) {
            $this->_params['hostspec'] = '';
        }

        /* Connect to the SQL server using the supplied parameters. */
        require_once 'DB.php';
        $this->_db = &DB::connect($this->_params,
                                  array('persistent' => !empty($this->_params['persistent'])));
        if (is_a($this->_db, 'PEAR_Error')) {
            Horde::fatal($this->_db, __FILE__, __LINE__);
        }

        // Set DB portability options.
        switch ($this->_db->phptype) {
        case 'mssql':
            $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
            break;
        default:
            $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
        }

        return true;
    }

}
