<?php
/**
 * @package Giapeto
 */

/**
 * Horde_Form_Action
 */
require_once 'Horde/Form/Action.php';

/**
 * Form_BlockEdit::
 *
 * These classes are used to set up the forms to edit individual
 * blocks within a page.
 *
 * $Horde: giapeto/lib/Form/BlockEdit.php,v 1.14 2007/01/02 12:47:39 jan Exp $
 *
 * Copyright 2002-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */
class Form_BlockEdit {

    var $_form;
    var $_vars;
    var $_type_change = false;
    var $_block = array();

    function Form_BlockEdit(&$vars, $block)
    {
        $this->_vars = &$vars;
        $this->_block = $block;

        $this->_form = new Horde_Form($vars, _("Block Edit"));

        /* These are the core components of the form, each block type
         * will then add their own additional fields. */
        $this->_form->setButtons(_("Update"), true);
        $this->_form->addHidden('', 'page_id', 'int', true);
        $this->_form->addHidden('', 'id', 'int', false);
        $this->_form->addVariable(_("Block title"), 'title', 'text', false);
        $v = &$this->_form->addVariable(_("Block type"), 'type', 'enum', false, false, null, array(Giapeto::getBlockTypes()));
        $v->setAction(Horde_Form_Action::factory('submit'));
        $v->setOption('trackchange', true);

        /* Check if block type has been changed. */
        $this->_type_change = (!is_null($vars->get('formname')) &&
                               $vars->get($v->getVarName()) !=
                               $vars->get('__old_' . $v->getVarName()) &&
                               $this->_form->isSubmitted());
    }

    function changedType()
    {
        return $this->_type_change;
    }

    function setEditVars()
    {
        /* Only set the vars from backend for editing if the form has
         * not been cleared for submit and there is no block type
         * set. */
        if (!$this->_form->isSubmitted() && isset($this->_block['type']) &&
            $this->_vars->get('type') == $this->_block['type']) {
            $this->_block['page_id'] = $this->_vars->get('page_id');
            $this->setBlock();
            $this->_vars = new Variables($this->_block);
        }
    }

    function validate()
    {
        if ($this->_form->validate($this->_vars)) {
            return $this->doSubmit();
        }
    }

    function doSubmit()
    {
        if (!$this->_form->isValid()) {
            return false;
        }
        $this->_form->getInfo($this->_vars, $info);
        $save = $GLOBALS['page']->setBlockData($info);
        if (is_a($save, 'PEAR_Error')) {
            return $save;
        }
        return $GLOBALS['page']->save();
    }

    function getForm()
    {
        require_once 'Horde/Form/Renderer.php';
        $params = array('varrenderer_driver' => array('giapeto', 'blockedit_html'));
        $renderer = new Horde_Form_Renderer($params);
        return Util::bufferOutput(array($this->_form, 'renderActive'), $renderer, $this->_vars, 'blockedit.php', 'post');
    }

    function setBlock()
    {
    }

    function &factory(&$vars)
    {
        /* Check if there is existing content. */
        $block_id = $vars->get('id');
        $block = $GLOBALS['page']->getBlock($block_id);
        $block['id'] = $block_id;

        $type = $vars->get('type');
        $types = Giapeto::getBlockTypes();
        if (empty($type) || !isset($types[$type])) {
            $type = (isset($block['type']) ? $block['type'] : 'text');
            $vars->set('type', $type);
        }

        require_once GIAPETO_BASE . '/lib/Form/BlockEdit/' . $type . '.php';
        $class = 'Form_BlockEdit_' . $type;
        if (class_exists($class)) {
            $blockedit = &new $class($vars, $block);
        } else {
            $blockedit = PEAR::raiseError('Class definition of ' . $class . ' not found.');
        }

        return $blockedit;
    }

}
