<?php
/**
 * $Horde: giapeto/lib/Template.php,v 1.1 2006/10/08 04:12:31 chuck Exp $
 *
 * @package Giapeto
 */
class Giapeto_Template extends Horde_Template {

    /**
     * Parses all variables/tags in the template.
     *
     * @param string $contents  The unparsed template.
     *
     * @return string  The parsed template.
     */
    function parse($contents = null)
    {
        return $this->_parseBlocks(parent::parse($contents));
    }

    /**
     * Retrieve list of blocks present in the template source.
     *
     * @param string $filename  The file to fetch the template from.
     * @return mixed  An array of applications, or PEAR_Error on failure.
     */
    function listBlocks()
    {
        $blocks = array();
        if (preg_match_all('<block:([a-zA-Z0-9_]+:[a-zA-Z0-9_]+)>',
                           $this->_template, $matches, PREG_SET_ORDER)) {
            foreach ($matches as $match) {
                $blocks[] = $match[1];
            }
        }

        return $blocks;
    }

    /**
     * Parses block tags.
     *
     * Here we parse block tags in the form:
     *
     *  <block:app:name>
     *   <param:foo>foo parameter's value</param:foo>
     *   <param:bar>bar parameter's value</param:bar>
     *   <serial:baz>s:21:"baz parameter's value";</serial:baz>
     *  </block:app:name>
     *
     * ... and replace them with rendered application blocks.
     *
     * Block parameters are provided with the nested "param:foo" and
     * "serial:foo" tags.  The serial-style tags take a serialized PHP
     * value, so you can use it to provide array, boolean, and complex
     * type parameters.  The param-style tags provide string parameters.
     *
     * @access private
     *
     * @param string $contents  The unparsed contents of the file.
     *
     * @return string  The parsed contents of the file.
     */
    function _parseBlocks($contents)
    {
        return preg_replace('!<block:([a-zA-Z_0-9]+):([a-zA-Z_0-9]+)>(.*?)' .
                            '</block:([a-zA-Z_0-9]+):([a-zA-Z_0-9]+)>!se',
                            "\$this->_parseBlock('\\1', '\\2', '\\3')",
                            $contents);
    }

    /**
     * Handle the contents of one block tag.
     *
     * @access private
     */
    function _parseBlock($app, $name, $contents)
    {
        require_once 'Horde/Block.php';
        require_once 'Horde/Block/Collection.php';

        // Undo preg_replace() encoding strangeness.
        $contents = str_replace('\\"', '"', $contents);

        // Find block's parameters.
        $params = array();
        if (preg_match_all('!<param:([a-zA-Z_0-9]+)>(.*?)' .
                           '</param:([a-zA-Z_0-9]+)>!s', $contents, $matches,
                           PREG_SET_ORDER)) {
            foreach ($matches as $match) {
                $params[$match[1]] = html_entity_decode($match[2]);
            }
        }
        if (preg_match_all('!<serial:([a-zA-Z_0-9]+)>(.*?)' .
                           '</serial:([a-zA-Z_0-9]+)>!s', $contents, $matches,
                           PREG_SET_ORDER)) {
            foreach ($matches as $match) {
                $params[$match[1]] = unserialize(html_entity_decode($match[2]));
            }
        }

        // Construct the block.
        $block = Horde_Block_Collection::getBlock($app, $name, $params);
        if (is_a($block, 'PEAR_Error')) {
            $result = '<strong>' . sprintf(_("Error creating block: %s"),
                                           $block->getMessage()) . '</strong>';
        } else {
            $result = $block->getContent();
            if (is_a($result, 'PEAR_Error')) {
                $result = '<strong>' . sprintf(_("Error getting content: %s"),
                                               $result->getMessage()) . '</strong>';
            }
        }

        return $result;
    }

}
