<?php
/**
 * Giapeto external API interface.
 *
 * This file defines Giapeto's external API interface. Other applications can
 * interact with Giapeto through this API.
 *
 * Copyright 2002-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/lib/api.php,v 1.18 2007/01/02 12:47:38 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */

$_services['perms'] = array(
    'args' => array(),
    'type' => '{urn:horde}stringArray'
);

$_services['listPages'] = array(
    'args' => array('root_page' => 'int'),
    'type' => '{urn:horde}stringArray'
);

$_services['getPageName'] = array(
    'args' => array('page_id' => 'int'),
    'type' => 'string'
);

$_services['getPageUrl'] = array(
    'args' => array('page_id' => 'int'),
    'type' => 'string'
);


function _giapeto_perms()
{
    static $perms = array();
    if (!empty($perms)) {
        return $perms;
    }

    require_once dirname(__FILE__) . '/base.php';

    /* Set up the giapeto class */
    $giapeto = &Giapeto::singleton();

    /* Available Giapeto permissions. */
    $perms = array();
    $perms['tree']['giapeto']['pages'] = array();
    $perms['title']['giapeto:pages'] = _("Pages");

    $sitetree = $giapeto->getSiteTree('cat_ids', DATATREE_ROOT, false, true);

    /* Loop through giapeto pages and add their titles. */
    foreach ($sitetree as $page_id => $page) {
        /* No child perms are to be added to this level. */
        $perms['tree']['giapeto']['pages'][$page_id] = false;;

        /* Use a better name for the root home page. */
        if ($page == '__root') {
            $page = _("Home");
        }
        $perms['title']['giapeto:pages:' . $page_id] = $page;
    }

    return $perms;
}

function _giapeto_listPages($root_page = DATATREE_ROOT)
{
    require_once dirname(__FILE__) . '/base.php';
    $giapeto = &Giapeto::singleton();
    $sitetree = $giapeto->getSiteTree('cat_ids', $root_page, false, true);

    return $sitetree;
}

function _giapeto_getPageName($page_id)
{
    require_once dirname(__FILE__) . '/base.php';
    $giapeto = &Giapeto::singleton();
    $page_path = $giapeto->getPagePath($page_id);
    return DataTreeObject_Page::getShortName($page_path);
}

function _giapeto_getPageUrl($page_id)
{
    require_once dirname(__FILE__) . '/base.php';
    $giapeto = &Giapeto::singleton();
    return $giapeto->getIdUrl($page_id, DATATREE_ROOT);
}
