<?php
/**
 * The Giapeto script for working on the behaviour of modified pages.
 *
 * $Horde: giapeto/modified.php,v 1.21 2007/01/02 12:47:36 jan Exp $
 *
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('GIAPETO_BASE', dirname(__FILE__));
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

$giapeto = &Giapeto::singleton();

/* Set up the form variables. */
$vars = Variables::getDefaultVariables();
$page_id = $vars->get('page_id');
$page = &$giapeto->getPage($page_id);

/* Check if user authorised for this. */
if (!$giapeto_perms->checkPermissions($page_id, 'page', PERMS_EDIT)) {
    $notification->push(_("You are not authorized for this action."), 'horde.error');
    $url = $giapeto->getIdUrl($page_id, 1);
    header('Location: ' . $url);
    exit;
}

$form = new Horde_Form($vars, _("Modified Page"));

if (!$form->isSubmitted()) {
    $vars = $page->getPageAnnounce();
    $vars['page_id'] = $page_id;
    $vars = new Variables($vars);
}

/* Set up the form. */
$form->setButtons(_("Update"));
$form->addHidden('', 'page_id', 'int', true);
$form->addVariable(_("Page announce"), 'status', 'boolean', true);
$form->addVariable(_("Announce message"), 'message', 'longtext', false);

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $page->setPageAnnounce($info['status'], $info['message']);
    $result = $page->save();
    if (is_a($result, 'PEAR_Error')) {
        Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Modifying page announce failed. %s"), $result->getMessage()), 'horde.error');
    } else {
        $notification->push(_("Page announce modified."), 'horde.success');
        $url = $giapeto->getIdUrl($giapeto->getPageId($page), 1);
        header('Location: ' . $url);
        exit;
    }
}

/* Render the form. */
$renderer = new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'modified.php', 'post');

$template = new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
$template->set('main', $main);

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
