<?php
/**
 * The Giapeto script to output a page.
 *
 * $Horde: giapeto/pages.php,v 1.134 2007/01/02 12:47:36 jan Exp $
 *
 * Copyright 2002-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('GIAPETO_BASE', dirname(__FILE__));
require_once GIAPETO_BASE . '/lib/base.php';
require_once GIAPETO_BASE . '/lib/Template.php';

/* Set up the giapeto class */
$giapeto = &Giapeto::singleton();
$giapeto->setActionId(G_SHOWPAGE);
$page_id = $giapeto->getThisPageId();

if (is_a($page_id, 'PEAR_Error')) {
    /* Try to load the default root. */
    $page_id = $giapeto->getUrlCategoryId('__root');

    /* Can't find root or doesn't exist, try to auto-create it. */
    if (is_a($page_id, 'PEAR_Error')) {
        $page = &$giapeto->newPage('__root');
        /* Add simple layout. */
        $page->setPageLayout('[x/x/x]');
        $result = $page->save();
        /* One more sanity check; if we fail this one, give up. */
        if (is_a($result, 'PEAR_Error')) {
            Horde::fatal($result, __FILE__, __LINE__);
        }
        $page_id = $giapeto->getPageId($page);
    }
}

$page = &$giapeto->getPage($page_id);
if (is_a($page, 'PEAR_Error')) {
    Horde::fatal($page, __FILE__, __LINE__);
}

/* Do not show the page unless the current user (or guests) has read
 * permissions. */
if (!$giapeto_perms->checkPermissions($page_id, 'page', PERMS_READ)) {
    $notification->push(_("You are not authorized."), 'horde.error');
    $template = new Horde_Template();
    $template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
    $html = $template->fetch(GIAPETO_TEMPLATES . '/main/main.html');
    if (is_a($html, 'PEAR_ERROR')) {
        Horde::fatal($html, __FILE__, __LINE__);
    }
    require GIAPETO_TEMPLATES . '/common-header.inc';
    echo $html;
    require $registry->get('templates', 'horde') . '/common-footer.inc';
    exit;
}

$sitetree = $giapeto->getSiteTree('tag', DATATREE_ROOT, false, true);

/* Get the available site links, horde apps, etc. */
$appmenu = array();
if (isset($conf['menu']['apps']) && is_array($conf['menu']['apps'])) {
    foreach ($conf['menu']['apps'] as $app) {
        if ($registry->get('status', $app) != 'inactive') {
            $appmenu[] = Horde::link(Horde::url($registry->getInitialPage($app))) . $registry->get('name', $app) . '</a>';
        }
    }
}

/* Set up template tags. */
$template = new Giapeto_Template();
$template->setTemplate($vfs->read(GIAPETO_VFS_PATH . '/templates', $giapeto->getPageTemplate($page)));
$template->set('fullname', $fullname, true);
$template->set('menu', Giapeto::getMenu('string'));
$template->set('pagename', $page->getShortName());
$template->set('rooturl', $giapeto->getCategoryUrl($giapeto->getRootPageId()));
$template->set('basepages', $giapeto->getFormattedSubPages($giapeto->getRootPageId()));
$template->set('basepagesparts', $giapeto->getSubPages($giapeto->getRootPageId()));
$template->set('subpages', $giapeto->getFormattedSubPages($page_id), true);
$template->set('subpagesparts', $giapeto->getSubPages($page_id), true);
$template->set('navpath', $giapeto->getFormattedNavPath($page_id), true);
$template->set('navpathparts', $giapeto->getNavPath($page_id));
$template->set('appmenu', $appmenu, true);
$template->set('sitetree', $sitetree);
$template->set('pagecontent', vsprintf($page->getPageLayout(), $page->getBlocks()));

$modified = '';
if ($page->isPageModified() && $giapeto_perms->checkPermissions($page_id, 'page', PERMS_EDIT)) {
    $url = Util::addParameter(Horde::applicationUrl('modified.php'), 'page_id', $page_id);
    $modified = Horde::link($url, _("Modified page options")) . Horde::img('new.png') . '</a>';
}
$template->set('modified', $modified, true);
$template->set('timestamp', $page->getPageModified());

/* Set up some optional tags. */
if ($conf['site']['bookmarks']) {
    $template->set('bookmark', $bookmarks->getButton($page_id));
}
if ($conf['site']['stats']) {
    /* Calculate stats first then log this visit; otherwise, the last
     * visit would always be now. */
    $template->set('stats', $stats->getStats($page_id));
    $stats->log($page_id);
}

/* Set custom tags if any. */
Horde::callHook('_giapeto_hook_settags', array(&$template));

/* Set notification tag. */
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

/* Set up the css for any loaded apps. */
$cssApps = $page->getLoadedApps();
foreach ($template->listBlocks() as $blockname) {
    list($app, $block) = explode(':', $blockname);
    $cssApps[$app] = $app;
}

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->parse();
require $registry->get('templates', 'horde') . '/common-footer.inc';
