<?php
/**
 * The Giapeto script to edit permissions for a page.
 *
 * $Horde: giapeto/perms/edit.php,v 1.13 2007/01/02 12:47:41 jan Exp $
 *
 * Copyright 2004-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('GIAPETO_BASE', dirname(__FILE__) . '/..');
require_once GIAPETO_BASE . '/lib/base.php';

/* Set up the giapeto class */
$giapeto = &Giapeto::singleton();

$page_id = Util::getFormData('page_id');

$page = &$giapeto->getPage($page_id);
if (is_a($page, 'PEAR_Error')) {
    Horde::fatal($page, __FILE__, __LINE__);
}

/* Check if user authorised for this. */
if (!$giapeto_perms->checkPermissions($page_id, 'page', PERMS_EDIT)) {
    $notification->push(_("You are not authorized."), 'horde.error');
    $url = $giapeto->getIdUrl($page_id, 1);
    header('Location: ' . $url);
    exit;
}

$base_perms = array();
$user_perms = array();
$group_perms = array();
$perm_name = 'giapeto:pages:' . $page_id;
$permission = &$perms->getPermission($perm_name);

/* Set up the permissions edit form. */
require_once 'Horde/Perms/UI.php';
$perms_ui = &new Perms_UI($perms);
$perms_ui->setupEditForm($permission, array('page_id'));
$perms_ui->_form->addHidden('', 'page_id', 'text', false);

/* Validate the form. */
if ($perms_ui->validateEditForm($info)) {
    /* Update and save the permissions. */
    $permission->updatePermissions($info);
    $permission->save();

    $notification->push(sprintf(_("Updated permissions for \"%s\"."), $page->getShortName()), 'horde.success');
    $url = Horde::applicationUrl('perms/index.php', true);
    $url = Util::addParameter($url, 'page_id', $page_id);
    header('Location: ' . $url);
    exit;
}

/* Set up template tags. */
$template = &new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('tree', $giapeto->renderPermsTree($page_id, $page_id));
$template->set('form', Util::bufferOutput(array($perms_ui, 'renderForm')));

/* Set notification tag. */
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/perms/edit.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
