#!/usr/bin/php
<?php
/**
 * Example script to handle announcements of page updates to a mailing list.
 * Could be activated at regular intervals through a crontab entry.
 *
 * Most of this should be moved to the main Giapeto libs once mature.
 *
 * $Horde: giapeto/scripts/announce.php,v 1.11 2006/04/18 15:39:34 jan Exp $
 *
 */

/******************************************************************************/
/* Find the base file paths. */
@define('HORDE_BASE', dirname(__FILE__) . '/../..');
@define('GIAPETO_BASE', dirname(__FILE__) . '/..');

/* SQL params where to fetch the user emails from. */
$email_params = array(
        'phptype'  => 'mysql',
        'hostspec' => 'localhost',
        'protocol' => 'tcp',
        'username' => 'horde',       // Set your username here
        'password' => '*****',       // Set your password here
        'database' => 'horde',       // Set the db name here
        'table'    => 'horde_users', // Set the table name here
        'charset'  => 'iso-8859-1',
        'fields'   => array('user_id' => 'user_uid',   // User field
                            'email' => 'user_email')); // Email field

/* Server base for setting the base url in html attachments. */
$server_base = 'http://example.com/';

/* Giapeto template to use when displaying the html. */
$page_template = GIAPETO_BASE . '/config/templates/pages/__announce.html';

/* Announcement email sender. */
$from_email   = 'info@example.com';

/* Set this to true if you want the announcements to be processed. */
$live = false;
/******************************************************************************/

/* Do CLI checks and environment setup first. */
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

/* Make sure no one runs this from the web. */
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

/* Load the CLI environment. */
Horde_CLI::init();

require_once HORDE_BASE . '/lib/core.php';
require_once GIAPETO_BASE . '/lib/base.php';

$giapeto = &Giapeto::singleton();

/* Get the updated pages. */
$updated = $giapeto->getUpdatedPages();

/* Get the watched pages. */
$watched = $bookmarks->getWatchedPages();

$announce_list = array();
foreach ($updated as $page_id => $page) {
    foreach ($watched[$page_id] as $user_id => $announce) {
        if ($announce == 1) {
            $announce_list[$user_id][$page_id] = true;
        }
    }
}

/* Mail the updates. */
require_once 'Mail.php';
require_once 'Horde/MIME.php';
require_once 'Horde/MIME/Headers.php';
require_once 'Horde/MIME/Message.php';

/* Set up the mail headers and read the log file. */
$msg_headers = &new MIME_Headers();
$msg_headers->addReceivedHeader();
$msg_headers->addMessageIdHeader();
$msg_headers->addAgentHeader();
$msg_headers->addHeader('Date', date('r'));
$msg_headers->addHeader('From', $from_email);
$msg_headers->addHeader('Subject', 'info CRALfi.org');

/* Connect to the DB containing the email addresses. */
include_once 'DB.php';
$email_db = &DB::connect($email_params, true);

// Set DB portability options.
switch ($email_db->phptype) {
case 'mssql':
    $email_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
    break;
default:
    $email_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
}

foreach ($announce_list as $user_id => $pages) {
    $sql = sprintf('SELECT %s FROM %s WHERE %s = %s',
                   $email_params['fields']['email'],
                   $email_params['table'],
                   $email_params['fields']['user_id'],
                   $email_db->quote($user_id));
    $recipient = $email_db->getOne($sql);
    $msg_headers->addHeader('To', $recipient);
    $attachments = array();
    $message = '';
    foreach ($pages as $page_id => $p) {
        $page = &$giapeto->getPage($page_id);
        if (is_a($page, 'PEAR_Error')) {
            exit("Unknown page.\n");
        }

        $template = &new Horde_Template();
        $template->set('pagename', $page->getShortName());
        $template->set('navpathparts', $giapeto->getNavPath($page_id));
        $template->set('pagecontent', vsprintf($page->getPageLayout(), $page->getBlocks()));

        $html = sprintf("\n" . '<html><head><base href="%s"></head>', $server_base);
        $html .= $template->fetch($page_template);
        $html .= '</body></html>';

        $page_announce = $page->getPageAnnouncement();
        $message .= $page_announce['message'] . "\n";
        $attachments[] = $html;
    }

    $mime = &new MIME_Message();

    $basepart = &new MIME_Part('text/plain');
    $basepart->setContents($basepart->replaceEOL($message));
    $mime->addPart($basepart);

    $body = &new MIME_Part('multipart/mixed');
    foreach ($attachments as $part) {
        $body->addPart(new MIME_Part('text/html', $part));
    }

    $mime->addPart($body);
    $msg_headers->addMIMEHeaders($mime);

    if ($live) {
        $result = $mime->send($recipient, $msg_headers);
    }
}

exit;
